BinanceDataClientConfigBuilder

Struct BinanceDataClientConfigBuilder 

pub struct BinanceDataClientConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> BinanceDataClientConfigBuilder<S>

pub fn build(self) -> BinanceDataClientConfig
where S: IsComplete,

Finish building and return the requested object

pub fn product_types( self, value: Vec<BinanceProductType>, ) -> BinanceDataClientConfigBuilder<SetProductTypes<S>>
where S::ProductTypes: IsUnset,

Optional (Some / Option setters). Default: vec![BinanceProductType::Spot].

Product types to subscribe to.

pub fn maybe_product_types( self, value: Option<Vec<BinanceProductType>>, ) -> BinanceDataClientConfigBuilder<SetProductTypes<S>>
where S::ProductTypes: IsUnset,

Optional (Some / Option setters). Default: vec![BinanceProductType::Spot].

Product types to subscribe to.

pub fn environment( self, value: BinanceEnvironment, ) -> BinanceDataClientConfigBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters). Default: BinanceEnvironment::Mainnet.

Environment (mainnet or testnet).

pub fn maybe_environment( self, value: Option<BinanceEnvironment>, ) -> BinanceDataClientConfigBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters). Default: BinanceEnvironment::Mainnet.

Environment (mainnet or testnet).

pub fn base_url_http( self, value: String, ) -> BinanceDataClientConfigBuilder<SetBaseUrlHttp<S>>
where S::BaseUrlHttp: IsUnset,

Optional (Some / Option setters). Optional base URL override for HTTP API.

pub fn maybe_base_url_http( self, value: Option<String>, ) -> BinanceDataClientConfigBuilder<SetBaseUrlHttp<S>>
where S::BaseUrlHttp: IsUnset,

Optional (Some / Option setters). Optional base URL override for HTTP API.

pub fn base_url_ws( self, value: String, ) -> BinanceDataClientConfigBuilder<SetBaseUrlWs<S>>
where S::BaseUrlWs: IsUnset,

Optional (Some / Option setters). Optional base URL override for WebSocket.

Live USD-M Futures data overrides are normalized onto the matching /market/ws and /public/ws routes.

pub fn maybe_base_url_ws( self, value: Option<String>, ) -> BinanceDataClientConfigBuilder<SetBaseUrlWs<S>>
where S::BaseUrlWs: IsUnset,

Optional (Some / Option setters). Optional base URL override for WebSocket.

Live USD-M Futures data overrides are normalized onto the matching /market/ws and /public/ws routes.

pub fn api_key( self, value: String, ) -> BinanceDataClientConfigBuilder<SetApiKey<S>>
where S::ApiKey: IsUnset,

Optional (Some / Option setters). API key (Ed25519).

pub fn maybe_api_key( self, value: Option<String>, ) -> BinanceDataClientConfigBuilder<SetApiKey<S>>
where S::ApiKey: IsUnset,

Optional (Some / Option setters). API key (Ed25519).

pub fn api_secret( self, value: String, ) -> BinanceDataClientConfigBuilder<SetApiSecret<S>>
where S::ApiSecret: IsUnset,

Optional (Some / Option setters). API secret (Ed25519 base64-encoded or PEM).

pub fn maybe_api_secret( self, value: Option<String>, ) -> BinanceDataClientConfigBuilder<SetApiSecret<S>>
where S::ApiSecret: IsUnset,

Optional (Some / Option setters). API secret (Ed25519 base64-encoded or PEM).

pub fn instrument_status_poll_secs( self, value: u64, ) -> BinanceDataClientConfigBuilder<SetInstrumentStatusPollSecs<S>>
where S::InstrumentStatusPollSecs: IsUnset,

Optional (Some / Option setters). Default: 3600.

Interval in seconds for polling exchange info to detect instrument status changes (e.g. Trading -> Halt). Set to 0 to disable. Defaults to 3600 (60 minutes).

pub fn maybe_instrument_status_poll_secs( self, value: Option<u64>, ) -> BinanceDataClientConfigBuilder<SetInstrumentStatusPollSecs<S>>
where S::InstrumentStatusPollSecs: IsUnset,

Optional (Some / Option setters). Default: 3600.

Interval in seconds for polling exchange info to detect instrument status changes (e.g. Trading -> Halt). Set to 0 to disable. Defaults to 3600 (60 minutes).

pub fn transport_backend( self, value: TransportBackend, ) -> BinanceDataClientConfigBuilder<SetTransportBackend<S>>
where S::TransportBackend: IsUnset,

Optional (Some / Option setters). Default: <TransportBackend as Default>::default().

WebSocket transport backend (defaults to Tungstenite).

pub fn maybe_transport_backend( self, value: Option<TransportBackend>, ) -> BinanceDataClientConfigBuilder<SetTransportBackend<S>>
where S::TransportBackend: IsUnset,

Optional (Some / Option setters). Default: <TransportBackend as Default>::default().

WebSocket transport backend (defaults to Tungstenite).