BinanceExecutionClientConfigBuilder

Struct BinanceExecutionClientConfigBuilder 

pub struct BinanceExecutionClientConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> BinanceExecutionClientConfigBuilder<S>

pub fn build(self) -> BinanceExecutionClientConfig
where S: IsComplete,

Finish building and return the requested object

pub fn account_id( self, value: AccountId, ) -> BinanceExecutionClientConfigBuilder<SetAccountId<S>>
where S::AccountId: IsUnset,

Optional (Some / Option setters). Default: AccountId::from("BINANCE-001").

Account ID for the client.

pub fn maybe_account_id( self, value: Option<AccountId>, ) -> BinanceExecutionClientConfigBuilder<SetAccountId<S>>
where S::AccountId: IsUnset,

Optional (Some / Option setters). Default: AccountId::from("BINANCE-001").

Account ID for the client.

pub fn product_type( self, value: BinanceProductType, ) -> BinanceExecutionClientConfigBuilder<SetProductType<S>>
where S::ProductType: IsUnset,

Optional (Some / Option setters). Default: BinanceProductType::Spot.

Product type to trade.

pub fn maybe_product_type( self, value: Option<BinanceProductType>, ) -> BinanceExecutionClientConfigBuilder<SetProductType<S>>
where S::ProductType: IsUnset,

Optional (Some / Option setters). Default: BinanceProductType::Spot.

Product type to trade.

pub fn environment( self, value: BinanceEnvironment, ) -> BinanceExecutionClientConfigBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters). Default: BinanceEnvironment::Live.

Environment (live, testnet, or demo).

pub fn maybe_environment( self, value: Option<BinanceEnvironment>, ) -> BinanceExecutionClientConfigBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters). Default: BinanceEnvironment::Live.

Environment (live, testnet, or demo).

pub fn base_url_http( self, value: String, ) -> BinanceExecutionClientConfigBuilder<SetBaseUrlHttp<S>>
where S::BaseUrlHttp: IsUnset,

Optional (Some / Option setters). Optional base URL override for HTTP API.

pub fn maybe_base_url_http( self, value: Option<String>, ) -> BinanceExecutionClientConfigBuilder<SetBaseUrlHttp<S>>
where S::BaseUrlHttp: IsUnset,

Optional (Some / Option setters). Optional base URL override for HTTP API.

pub fn base_url_ws( self, value: String, ) -> BinanceExecutionClientConfigBuilder<SetBaseUrlWs<S>>
where S::BaseUrlWs: IsUnset,

Optional (Some / Option setters). Optional base URL override for WebSocket user data stream.

Live USD-M Futures stream overrides are normalized onto the /private/ws route.

pub fn maybe_base_url_ws( self, value: Option<String>, ) -> BinanceExecutionClientConfigBuilder<SetBaseUrlWs<S>>
where S::BaseUrlWs: IsUnset,

Optional (Some / Option setters). Optional base URL override for WebSocket user data stream.

Live USD-M Futures stream overrides are normalized onto the /private/ws route.

pub fn base_url_ws_trading( self, value: String, ) -> BinanceExecutionClientConfigBuilder<SetBaseUrlWsTrading<S>>
where S::BaseUrlWsTrading: IsUnset,

Optional (Some / Option setters). Optional base URL override for WebSocket trading API (Spot and USD-M Futures).

pub fn maybe_base_url_ws_trading( self, value: Option<String>, ) -> BinanceExecutionClientConfigBuilder<SetBaseUrlWsTrading<S>>
where S::BaseUrlWsTrading: IsUnset,

Optional (Some / Option setters). Optional base URL override for WebSocket trading API (Spot and USD-M Futures).

pub fn use_ws_trading( self, value: bool, ) -> BinanceExecutionClientConfigBuilder<SetUseWsTrading<S>>
where S::UseWsTrading: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to use the WebSocket trading API for order operations (Spot and USD-M Futures).

pub fn maybe_use_ws_trading( self, value: Option<bool>, ) -> BinanceExecutionClientConfigBuilder<SetUseWsTrading<S>>
where S::UseWsTrading: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to use the WebSocket trading API for order operations (Spot and USD-M Futures).

pub fn ws_trading_setup_timeout_ms( self, value: u64, ) -> BinanceExecutionClientConfigBuilder<SetWsTradingSetupTimeoutMs<S>>
where S::WsTradingSetupTimeoutMs: IsUnset,

Optional (Some / Option setters). Default: 10_000.

Timeout in milliseconds for each Binance Spot WS trading setup response.

pub fn maybe_ws_trading_setup_timeout_ms( self, value: Option<u64>, ) -> BinanceExecutionClientConfigBuilder<SetWsTradingSetupTimeoutMs<S>>
where S::WsTradingSetupTimeoutMs: IsUnset,

Optional (Some / Option setters). Default: 10_000.

Timeout in milliseconds for each Binance Spot WS trading setup response.

pub fn instrument_provider( self, value: BinanceInstrumentProviderConfig, ) -> BinanceExecutionClientConfigBuilder<SetInstrumentProvider<S>>
where S::InstrumentProvider: IsUnset,

Optional (Some / Option setters). Default: <BinanceInstrumentProviderConfig as Default>::default().

Instrument loading and fee configuration.

pub fn maybe_instrument_provider( self, value: Option<BinanceInstrumentProviderConfig>, ) -> BinanceExecutionClientConfigBuilder<SetInstrumentProvider<S>>
where S::InstrumentProvider: IsUnset,

Optional (Some / Option setters). Default: <BinanceInstrumentProviderConfig as Default>::default().

Instrument loading and fee configuration.

pub fn instrument_refresh_interval_secs( self, value: u64, ) -> BinanceExecutionClientConfigBuilder<SetInstrumentRefreshIntervalSecs<S>>
where S::InstrumentRefreshIntervalSecs: IsUnset,

Optional (Some / Option setters). Default: 3600.

Interval in seconds for refreshing the execution instrument cache.

Set to 0 to disable. Defaults to 3600 (60 minutes).

pub fn maybe_instrument_refresh_interval_secs( self, value: Option<u64>, ) -> BinanceExecutionClientConfigBuilder<SetInstrumentRefreshIntervalSecs<S>>
where S::InstrumentRefreshIntervalSecs: IsUnset,

Optional (Some / Option setters). Default: 3600.

Interval in seconds for refreshing the execution instrument cache.

Set to 0 to disable. Defaults to 3600 (60 minutes).

pub fn use_gtd( self, value: bool, ) -> BinanceExecutionClientConfigBuilder<SetUseGtd<S>>
where S::UseGtd: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to use Binance-native GTD orders.

Set to false only when the strategy manages GTD expiry locally. The adapter then maps GTD to GTC and the strategy must enable manage_gtd_expiry.

pub fn maybe_use_gtd( self, value: Option<bool>, ) -> BinanceExecutionClientConfigBuilder<SetUseGtd<S>>
where S::UseGtd: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to use Binance-native GTD orders.

Set to false only when the strategy manages GTD expiry locally. The adapter then maps GTD to GTC and the strategy must enable manage_gtd_expiry.

pub fn use_position_ids( self, value: bool, ) -> BinanceExecutionClientConfigBuilder<SetUsePositionIds<S>>
where S::UsePositionIds: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to use canonical Binance Futures position IDs.

When true, Futures hedge-mode order and fill reports include a venue_position_id derived from the instrument and Binance position side (e.g. ETHUSDT-PERP.BINANCE-LONG). Hedge-mode REST position reports use the same IDs. One-way BOTH reports remain unkeyed. When false, venue_position_id is None, allowing virtual positions with OmsType::Hedging.

pub fn maybe_use_position_ids( self, value: Option<bool>, ) -> BinanceExecutionClientConfigBuilder<SetUsePositionIds<S>>
where S::UsePositionIds: IsUnset,

Optional (Some / Option setters). Default: true.

Whether to use canonical Binance Futures position IDs.

When true, Futures hedge-mode order and fill reports include a venue_position_id derived from the instrument and Binance position side (e.g. ETHUSDT-PERP.BINANCE-LONG). Hedge-mode REST position reports use the same IDs. One-way BOTH reports remain unkeyed. When false, venue_position_id is None, allowing virtual positions with OmsType::Hedging.

pub fn oms_type( self, value: OmsType, ) -> BinanceExecutionClientConfigBuilder<SetOmsType<S>>
where S::OmsType: IsUnset,

Optional (Some / Option setters). Optional OMS type override for Binance Futures accounts.

Set to Hedging when the account uses dual-side position mode. When None, Binance Futures clients use Netting. Ignored for Spot clients.

pub fn maybe_oms_type( self, value: Option<OmsType>, ) -> BinanceExecutionClientConfigBuilder<SetOmsType<S>>
where S::OmsType: IsUnset,

Optional (Some / Option setters). Optional OMS type override for Binance Futures accounts.

Set to Hedging when the account uses dual-side position mode. When None, Binance Futures clients use Netting. Ignored for Spot clients.

pub fn default_taker_fee( self, value: Decimal, ) -> BinanceExecutionClientConfigBuilder<SetDefaultTakerFee<S>>
where S::DefaultTakerFee: IsUnset,

Optional (Some / Option setters). Default: Decimal::new(4, 4).

Default taker fee rate for commission estimation.

Used as a fallback when the venue omits commission fields in exchange-generated fills (liquidation, ADL, settlement). Standard Binance Futures taker fee is 0.0004 (0.04%).

pub fn maybe_default_taker_fee( self, value: Option<Decimal>, ) -> BinanceExecutionClientConfigBuilder<SetDefaultTakerFee<S>>
where S::DefaultTakerFee: IsUnset,

Optional (Some / Option setters). Default: Decimal::new(4, 4).

Default taker fee rate for commission estimation.

Used as a fallback when the venue omits commission fields in exchange-generated fills (liquidation, ADL, settlement). Standard Binance Futures taker fee is 0.0004 (0.04%).

pub fn proxy_url( self, value: String, ) -> BinanceExecutionClientConfigBuilder<SetProxyUrl<S>>
where S::ProxyUrl: IsUnset,

Optional (Some / Option setters). Optional proxy URL for HTTP and WebSocket transports.

pub fn maybe_proxy_url( self, value: Option<String>, ) -> BinanceExecutionClientConfigBuilder<SetProxyUrl<S>>
where S::ProxyUrl: IsUnset,

Optional (Some / Option setters). Optional proxy URL for HTTP and WebSocket transports.

pub fn recv_window_ms( self, value: u64, ) -> BinanceExecutionClientConfigBuilder<SetRecvWindowMs<S>>
where S::RecvWindowMs: IsUnset,

Optional (Some / Option setters). Default: 5_000.

Receive window in milliseconds for signed HTTP requests.

pub fn maybe_recv_window_ms( self, value: Option<u64>, ) -> BinanceExecutionClientConfigBuilder<SetRecvWindowMs<S>>
where S::RecvWindowMs: IsUnset,

Optional (Some / Option setters). Default: 5_000.

Receive window in milliseconds for signed HTTP requests.

pub fn us(self, value: bool) -> BinanceExecutionClientConfigBuilder<SetUs<S>>
where S::Us: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to route this Spot client to Binance US.

pub fn maybe_us( self, value: Option<bool>, ) -> BinanceExecutionClientConfigBuilder<SetUs<S>>
where S::Us: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to route this Spot client to Binance US.

pub fn api_key( self, value: String, ) -> BinanceExecutionClientConfigBuilder<SetApiKey<S>>
where S::ApiKey: IsUnset,

Optional (Some / Option setters). API key (uses an environment variable if not provided).

pub fn maybe_api_key( self, value: Option<String>, ) -> BinanceExecutionClientConfigBuilder<SetApiKey<S>>
where S::ApiKey: IsUnset,

Optional (Some / Option setters). API key (uses an environment variable if not provided).

pub fn api_secret( self, value: String, ) -> BinanceExecutionClientConfigBuilder<SetApiSecret<S>>
where S::ApiSecret: IsUnset,

Optional (Some / Option setters). API secret (Ed25519 for Global or HMAC for Binance US).

pub fn maybe_api_secret( self, value: Option<String>, ) -> BinanceExecutionClientConfigBuilder<SetApiSecret<S>>
where S::ApiSecret: IsUnset,

Optional (Some / Option setters). API secret (Ed25519 for Global or HMAC for Binance US).

pub fn futures_leverages( self, value: HashMap<String, u32>, ) -> BinanceExecutionClientConfigBuilder<SetFuturesLeverages<S>>
where S::FuturesLeverages: IsUnset,

Optional (Some / Option setters). Initial leverage per Binance symbol (e.g. BTCUSDT -> 20), applied during connect.

pub fn maybe_futures_leverages( self, value: Option<HashMap<String, u32>>, ) -> BinanceExecutionClientConfigBuilder<SetFuturesLeverages<S>>
where S::FuturesLeverages: IsUnset,

Optional (Some / Option setters). Initial leverage per Binance symbol (e.g. BTCUSDT -> 20), applied during connect.

pub fn futures_margin_types( self, value: HashMap<String, BinanceMarginType>, ) -> BinanceExecutionClientConfigBuilder<SetFuturesMarginTypes<S>>
where S::FuturesMarginTypes: IsUnset,

Optional (Some / Option setters). Margin type per Binance symbol (e.g. BTCUSDT -> Cross), applied during connect.

pub fn maybe_futures_margin_types( self, value: Option<HashMap<String, BinanceMarginType>>, ) -> BinanceExecutionClientConfigBuilder<SetFuturesMarginTypes<S>>
where S::FuturesMarginTypes: IsUnset,

Optional (Some / Option setters). Margin type per Binance symbol (e.g. BTCUSDT -> Cross), applied during connect.

pub fn bnfcr_currency( self, value: Currency, ) -> BinanceExecutionClientConfigBuilder<SetBnfcrCurrency<S>>
where S::BnfcrCurrency: IsUnset,

Optional (Some / Option setters). Default: Currency::USDT().

Currency that Binance Futures Credits (BNFCR) balances and fees resolve to (defaults to USDT).

pub fn maybe_bnfcr_currency( self, value: Option<Currency>, ) -> BinanceExecutionClientConfigBuilder<SetBnfcrCurrency<S>>
where S::BnfcrCurrency: IsUnset,

Optional (Some / Option setters). Default: Currency::USDT().

Currency that Binance Futures Credits (BNFCR) balances and fees resolve to (defaults to USDT).

pub fn treat_expired_as_canceled( self, value: bool, ) -> BinanceExecutionClientConfigBuilder<SetTreatExpiredAsCanceled<S>>
where S::TreatExpiredAsCanceled: IsUnset,

Optional (Some / Option setters). Default: false.

If true, the EXPIRED execution type emits OrderCanceled instead of OrderExpired.

Binance uses EXPIRED for certain cancel scenarios depending on order type and time-in-force combination.

pub fn maybe_treat_expired_as_canceled( self, value: Option<bool>, ) -> BinanceExecutionClientConfigBuilder<SetTreatExpiredAsCanceled<S>>
where S::TreatExpiredAsCanceled: IsUnset,

Optional (Some / Option setters). Default: false.

If true, the EXPIRED execution type emits OrderCanceled instead of OrderExpired.

Binance uses EXPIRED for certain cancel scenarios depending on order type and time-in-force combination.

pub fn use_trade_lite( self, value: bool, ) -> BinanceExecutionClientConfigBuilder<SetUseTradeLite<S>>
where S::UseTradeLite: IsUnset,

Optional (Some / Option setters). Default: false.

If true, drive fills from the lower-latency TRADE_LITE user data event and dedup the matching fill portion of ORDER_TRADE_UPDATE. If false, TRADE_LITE events are ignored and fills come from ORDER_TRADE_UPDATE.

pub fn maybe_use_trade_lite( self, value: Option<bool>, ) -> BinanceExecutionClientConfigBuilder<SetUseTradeLite<S>>
where S::UseTradeLite: IsUnset,

Optional (Some / Option setters). Default: false.

If true, drive fills from the lower-latency TRADE_LITE user data event and dedup the matching fill portion of ORDER_TRADE_UPDATE. If false, TRADE_LITE events are ignored and fills come from ORDER_TRADE_UPDATE.

pub fn transport_backend( self, value: TransportBackend, ) -> BinanceExecutionClientConfigBuilder<SetTransportBackend<S>>
where S::TransportBackend: IsUnset,

Optional (Some / Option setters). Default: <TransportBackend as Default>::default().

WebSocket transport backend (defaults to Tungstenite).

pub fn maybe_transport_backend( self, value: Option<TransportBackend>, ) -> BinanceExecutionClientConfigBuilder<SetTransportBackend<S>>
where S::TransportBackend: IsUnset,

Optional (Some / Option setters). Default: <TransportBackend as Default>::default().

WebSocket transport backend (defaults to Tungstenite).